@@ -69,6 +69,7 @@ import com.openexchange.mobile.api.facade.connectors.impl.DeleteFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.DeleteMailsConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.EnvelopesConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.ExamineMultipleFoldersConnector;
+import com.openexchange.mobile.api.facade.connectors.impl.ExpungeFolderConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetAccountConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetJsLobConnector;
 import com.openexchange.mobile.api.facade.connectors.impl.GetMailConnector;
@@ -123,6 +124,8 @@ public interface ConnectorFactory {
 
     ExamineMultipleFoldersConnector getExamineMultipleFoldersConnector(SessionData sessionData, List<Folder> folderIds);
 
+    ExpungeFolderConnector getExpungeFolderConnector(SessionData sessionData, String folderId);
+
     GetJsLobConnector getGetJsLobConnector(SessionData sessionData, String name);
 
     GetMailConnector getGetMailConnector(SessionData sessionData, String folderId, String mailId);
