@@ -136,6 +136,11 @@ public class DefaultConnectorFactory implements ConnectorFactory {
         return new EnvelopesConnector(configuration, sessionData, folderId, mailIds);
     }
 
+    @Override
+    public ExpungeFolderConnector getExpungeFolderConnector(SessionData sessionData, String folderId) {
+        return new ExpungeFolderConnector(configuration, sessionData, folderId);
+    }
+
     @Override
     public ExamineMultipleFoldersConnector getExamineFolderConnector(SessionData sessionData, String folderId) {
         return new ExamineMultipleFoldersConnector(configuration, sessionData, folderId);
