@@ -57,6 +57,7 @@ import javax.ws.rs.Consumes;
 import javax.ws.rs.DELETE;
 import javax.ws.rs.GET;
 import javax.ws.rs.POST;
+import javax.ws.rs.PUT;
 import javax.ws.rs.Path;
 import javax.ws.rs.Produces;
 import javax.ws.rs.core.Context;
@@ -67,12 +68,15 @@ import com.openexchange.mobile.api.facade.auth.SessionData;
 import com.openexchange.mobile.api.facade.endpoints.requests.ExamineFolderRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.requests.FolderCreateRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.requests.FolderRequestBody;
+import com.openexchange.mobile.api.facade.endpoints.requests.FolderUpdateRequestBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.AccountsResponseBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.CreateFolderResponseBody;
 import com.openexchange.mobile.api.facade.endpoints.responses.ExamineFolderResponseBody;
+import com.openexchange.mobile.api.facade.endpoints.responses.UpdatedFolderResponseBody;
 import com.openexchange.mobile.api.facade.models.Account;
 import com.openexchange.mobile.api.facade.models.CreatedFolder;
 import com.openexchange.mobile.api.facade.models.ExamineResult;
+import com.openexchange.mobile.api.facade.models.UpdatedFolder;
 import com.openexchange.mobile.api.facade.services.FoldersService;
 import com.openexchange.mobile.api.facade.utils.JacksonUtil;
 import com.openexchange.mobile.api.facade.utils.RequestUtil;
@@ -86,6 +90,8 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public class FoldersEndpoint {
 
+    private static final String FIELD_FOLDER_ID = "folderId";
+
     private final FoldersService foldersService;
 
     @POST
@@ -100,6 +106,19 @@ public class FoldersEndpoint {
         return RequestUtil.jsonResponse(201, responseBody);
     }
 
+    @PUT
+    @Consumes(MediaType.APPLICATION_JSON)
+    @Produces(MediaType.APPLICATION_JSON)
+    public Response updateFolder(@Context HttpServletRequest request, String rawRequestBody) {
+        SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Update folder");
+        FolderUpdateRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderUpdateRequestBody.class);
+        RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
+        UpdatedFolder folder = foldersService.updateFolder(sessionData, requestBody.getFolderId(), requestBody.getNewParentFolderId(), requestBody.getNewName());
+        UpdatedFolderResponseBody responseBody = new UpdatedFolderResponseBody(folder);
+        return RequestUtil.jsonResponse(200, responseBody);
+    }
+
     @DELETE
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
@@ -115,7 +134,7 @@ public class FoldersEndpoint {
     @Path("/clear")
     @Consumes(MediaType.APPLICATION_JSON)
     @Produces(MediaType.APPLICATION_JSON)
-    public Response expungeFolder(@Context HttpServletRequest request, String rawRequestBody) {
+    public Response clearFolder(@Context HttpServletRequest request, String rawRequestBody) {
         SessionData sessionData = RequestUtil.getSessionData(request);
         log.info("Clear folder");
         FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
@@ -123,6 +142,18 @@ public class FoldersEndpoint {
         return RequestUtil.emptyJsonResponse();
     }
 
+    @DELETE
+    @Path("/expunge")
+    @Consumes(MediaType.APPLICATION_JSON)
+    @Produces(MediaType.APPLICATION_JSON)
+    public Response expungeFolder(@Context HttpServletRequest request, String rawRequestBody) {
+        SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Expunge folder");
+        FolderRequestBody requestBody = JacksonUtil.parse(rawRequestBody, FolderRequestBody.class);
+        foldersService.expungeFolder(sessionData, requestBody.getFolderId());
+        return RequestUtil.emptyJsonResponse();
+    }
+
     @GET
     @Path("/mail")
     @Produces(MediaType.APPLICATION_JSON)
