@@ -130,7 +130,7 @@ public class MailsEndpoint {
     @Produces(MediaType.APPLICATION_JSON)
     public Response getStubs(@Context HttpServletRequest request, String rawRequestBody) {
         SessionData sessionData = RequestUtil.getSessionData(request);
-        log.error("Retrieving stubs");
+        log.info("Retrieving stubs");
         MailsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, MailsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         boolean threaded = RequestUtil.getBooleanParameter(requestBody.getThreaded(), true);
@@ -329,6 +329,7 @@ public class MailsEndpoint {
 
     private Response setFlags(HttpServletRequest request, String rawRequestBody, MailFlags flags) {
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Setting flags");
         SetFlagsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetFlagsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
@@ -428,6 +429,7 @@ public class MailsEndpoint {
 
     private Response clearFlags(HttpServletRequest request, String rawRequestBody, MailFlags flags) {
         SessionData sessionData = RequestUtil.getSessionData(request);
+        log.info("Clearing flags");
         SetFlagsRequestBody requestBody = JacksonUtil.parse(rawRequestBody, SetFlagsRequestBody.class);
         RequestUtil.checkParam(FIELD_FOLDER_ID, requestBody.getFolderId());
         RequestUtil.checkParam(FIELD_MAIL_IDS, requestBody.getMailIds());
