@@ -53,9 +53,14 @@ import java.util.List;
 
 import com.openexchange.mobile.api.facade.endpoints.responses.ctos.AliasCto;
 
+import lombok.AccessLevel;
+import lombok.AllArgsConstructor;
+import lombok.NoArgsConstructor;
 import lombok.Value;
 
 @Value
+@AllArgsConstructor
+@NoArgsConstructor(force = true, access = AccessLevel.PRIVATE)
 public class AccountRequestBody {
 
     // General properties
