@@ -200,7 +200,6 @@ public class FoldersService {
     }
 
     private List<Folder> retrieveFolders(ConnectorFactory connectorFactory, SessionData sessionData, String rootFolderId, String archiveFolderId, String language) {
-        int userId = getUserId(sessionData);
         boolean includeNonPrivateFolders = sessionData.getConfiguration().isIncludeNonPrivateFolders();
         AllFoldersConnector connector = connectorFactory.getAllFoldersConnector(sessionData, rootFolderId, language);
         FoldersMto data;
@@ -219,19 +218,10 @@ public class FoldersService {
             return Collections.singletonList(inboxFolder);
         }
         return data != null
-                ? AllFoldersConnector.map(data.getPrivateFolders(), archiveFolderId, includeNonPrivateFolders, userId)
+                ? AllFoldersConnector.map(data.getPrivateFolders(), archiveFolderId, includeNonPrivateFolders)
                 : Collections.<Folder>emptyList();
     }
 
-    private int getUserId(SessionData sessionData) {
-        try {
-            String userId = sessionData.getProperty(SessionData.PROPERTY_USER_ID);
-            return Integer.valueOf(userId).intValue();
-        } catch (NumberFormatException e) {
-            return -1;
-        }
-    }
-
     /*private*/ void examineFolders(ConnectorFactory connectorFactory, SessionData sessionData, List<Folder> folders) {
         ExamineMultipleFoldersConnector connector = connectorFactory.getExamineMultipleFoldersConnector(sessionData, folders);
         List<ExamineResponseMto> responses = connector.execute();
